phone

# XMLRésuméLibrary: User Guide

period | Element Reference | possible

## Name

phone — A voice telephone number

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
location | Enumeration:
`home`
`work`
`mobile`
| None
targets | CDATA | None

## Description

The `phone` element contains a telephone number. The number is not required to be in a specific format; these are all valid phone numbers:

- `555-555-1212`

- `555.555.1212`

- `(555) 555-1212`

- `(555) 555-1212 x555`

- `(011) 47 8931-858128`

- `(011) 59-3331-8580`

### Parents

`phone` may be contained in these elements: `contact`

### Attributes

`location`

  Indicates the location that the phone number connects to. This attribute is optional.

## See Also

`address`, `email`, `fax`, `pager`.

## Examples

    <phone>555.555.1212</phone>

    <phone location="mobile">345-262-4567</phone>

    <phone location="home">(261) 345-1616</phone>

For additional examples, see `contact`.

period | Element Reference | possible